Args

Struct Args 

pub struct Args {
    pub config_file: Option<PathBuf>,
    pub pivot_pull_secret: Option<PathBuf>,
    /* private fields */
}
Create a new TVC deployment from a config file or CLI flags.

Fields

config_file: Option<PathBuf>

Path to the deployment configuration file (JSON). Optional when all required fields are provided via flags or env.

pivot_pull_secret: Option<PathBuf>

Path to an unencrypted pivot container pull secret file.

The content will be encrypted based on the active org’s API environment and override pivotContainerEncryptedPullSecret from the config file.