pub fn init()Expand description
Initialize process-wide diagnostic logging.
Logging is disabled by default to keep normal CLI output unchanged. Set
RUST_LOG, for example RUST_LOG=tvc=debug, to enable structured debug
diagnostics on stderr.
pub fn init()Initialize process-wide diagnostic logging.
Logging is disabled by default to keep normal CLI output unchanged. Set
RUST_LOG, for example RUST_LOG=tvc=debug, to enable structured debug
diagnostics on stderr.