Module util

Module util 

Shared utils for TVC CLI.

Functions

read_file_to_string
Read a file to string with contextual error information.
write_file
Write contents to a file with contextual error information.